@@ -16,7 +16,6 @@
 
 #pragma once
 
-#include <H3D/Macros.h>
 #include <string>
 #include <ft2build.h>
 #include FT_FREETYPE_H
@@ -24,14 +23,9 @@
 #include <GL/gl.h>
 #include <AL/al.h>
 #include <ode/ode.h>
-#undef PACKAGE
-#undef PACKAGE_BUGREPORT
-#undef PACKAGE_NAME
-#undef PACKAGE_STRING
-#undef PACKAGE_TARNAME
-#undef PACKAGE_VERSION
-#undef VERSION
+#include <H3D/Macros.h>
 #include <H3D/Mesh.h>
+#include <H3D/Image.h>
 
 namespace H3D
 {
@@ -105,6 +99,10 @@ namespace H3D
 					}
 					return format;
 				}
+
+				H3D_API
+				::H3D::Image::H3D *
+				Read(int x, int y, unsigned int width, unsigned int height, GLenum format = GL_RGBA);
 			}
 
 			namespace OpenDE
