@@ -102,7 +102,7 @@ namespace H3D
 						for(i = 0, j = 0; i < (unsigned int) glyph->outline.n_points; i++)
 						{
 							glVertex2i(glyph->outline.points[i].x / 64, glyph->outline.points[i].y / 64);
-							if(i == glyph->outline.contours[j])
+							if(i == (unsigned int) glyph->outline.contours[j])
 							{
 								glEnd();
 								if(j < (unsigned int) glyph->outline.n_contours - 1)
@@ -157,7 +157,7 @@ namespace H3D
 							vertices[i * 3 + 1] = (double) glyph->outline.points[i].y / 64;
 							vertices[i * 3 + 2] = 0;
 							gluTessVertex(tess, &vertices[i * 3], &vertices[i * 3]);
-							if(i == glyph->outline.contours[j])
+							if(i == (unsigned int) glyph->outline.contours[j])
 							{
 								gluTessEndContour(tess);
 								if(j < (unsigned int) glyph->outline.n_contours - 1)
@@ -190,7 +190,7 @@ namespace H3D
 						{
 							glVertex3i(glyph->outline.points[i].x / 64, glyph->outline.points[i].y / 64, - (int) z);
 							glVertex3i(glyph->outline.points[i].x / 64, glyph->outline.points[i].y / 64, 0);
-							if(i == glyph->outline.contours[j])
+							if(i == (unsigned int) glyph->outline.contours[j])
 							{
 								glEnd();
 								if(j < (unsigned int) glyph->outline.n_contours - 1)
@@ -238,6 +238,26 @@ namespace H3D
 				}
 			}
 
+			namespace Image
+			{
+				::H3D::Image::H3D *
+				Read(int x, int y, unsigned int width, unsigned int height, GLenum format)
+				{
+					::H3D::Image::H3D *image = new ::H3D::Image::H3D();
+					image->info.width = width;
+					image->info.height = height;
+					switch(format)
+					{
+						case GL_RGB: image->info.bpp = 3; break;
+						case GL_RGBA: image->info.bpp = 4; break;
+					}
+					image->content.pixels = new unsigned char[image->info.width * image->info.height * image->info.bpp];
+					glReadPixels(x, y, image->info.width, image->info.height, format, GL_UNSIGNED_BYTE, image->content.pixels);
+					return image;
+
+				}
+			}
+
 			namespace OpenDE
 			{
 				void
@@ -396,7 +416,7 @@ namespace H3D
 					if(!image->load(path + STRPS + content.textures[i].name))
 					{
 						delete image;
-						image = ::H3D::Image::NAME::import(path + STRPS + content.textures[i].name);
+						image = ::H3D::Image::NAME::Load(path + STRPS + content.textures[i].name);
 					}
 					if(image)
 					{
