@@ -37,9 +37,9 @@ namespace H3D
 		}
 
 		bool
-		H3D::load(const std::string& filename)
+		H3D::load(const std::string &filename)
 		{
-			FILE* stream;
+			FILE *stream;
 			bool result;
 			stream = fopen(filename.c_str(), "rb");
 			if(stream)
@@ -61,9 +61,9 @@ namespace H3D
 		}
 
 		bool
-		H3D::save(const std::string& filename)
+		H3D::save(const std::string &filename)
 		{
-			FILE* stream;
+			FILE *stream;
 			bool result;
 			stream = fopen(filename.c_str(), "wb");
 			if(stream)
@@ -79,8 +79,8 @@ namespace H3D
 
 		namespace PNG
 		{
-			H3D*
-			import(const std::string& filename)
+			H3D *
+			Load(const std::string &filename)
 			{
 				H3D* image;
 				FILE *stream; 
@@ -145,14 +145,62 @@ namespace H3D
 				else image = NULL;
 				return image;
 			}
+
+			bool
+			Save(H3D *image, const std::string &filename)
+			{
+				bool result;
+				FILE *stream; 
+				png_structp png; 
+				png_infop info;
+				unsigned long i;
+				png_bytepp rows;
+				rows = NULL;
+				stream = fopen(filename.c_str(), "wb");
+				if(stream)
+				{
+					png = png_create_write_struct(PNG_LIBPNG_VER_STRING, NULL, NULL, NULL);
+					if(png)
+					{
+						info = png_create_info_struct(png);
+						if (info)
+						{
+							if(!setjmp(png_jmpbuf(png)))
+							{
+								png_init_io(png, stream);
+								png_set_IHDR(png, info, image->info.width, image->info.height, 8, PNG_COLOR_TYPE_RGB_ALPHA, PNG_INTERLACE_NONE, PNG_COMPRESSION_TYPE_BASE, PNG_FILTER_TYPE_BASE);
+
+								png_write_info(png, info);
+								rows = (png_bytepp) malloc(image->info.height * sizeof(png_bytep));
+								for(i = 0; i < image->info.height; i++) rows[image->info.height - 1 - i] = image->content.pixels + i * image->info.width * image->info.bpp;
+								png_write_image(png, rows);
+								free(rows);
+								png_write_end(png, info);
+								result= true;
+							}
+							else result = false;
+							png_destroy_write_struct(&png, &info);
+						}
+						else
+						{
+							png_destroy_write_struct(&png, (png_infopp) NULL);
+							result = false;
+						}
+					}
+					else result = false;
+					fclose(stream);
+				}
+				else result = false;
+				return result;
+			}
 		}
 
 		namespace JPEG
 		{
-			H3D*
-			import(const std::string& filename)
+			H3D *
+			Load(const std::string &filename)
 			{
-				H3D* image;
+				H3D *image;
 				FILE *stream; 
 				struct jpeg_decompress_struct decompress;
 				struct jpeg_error_mgr error;
@@ -169,10 +217,10 @@ namespace H3D
 					jpeg_start_decompress(&decompress);
 					image->info.width = (unsigned int) Math::NextTwoPower(decompress.image_width);
 					image->info.height = (unsigned int) Math::NextTwoPower(decompress.image_height);
-					image->info.bpp = 3;
+					image->info.bpp = decompress.output_components;
 					image->content.pixels = new unsigned char[image->info.width * image->info.height * image->info.bpp];
 					rows = (unsigned char **) malloc(decompress.image_height * sizeof(unsigned char *));
-					for(i = 0; i < decompress.image_height; i++) rows[i] = image->content.pixels + i * decompress.image_width * image->info.bpp;
+					for(i = 0; i < decompress.image_height; i++) rows[i] = image->content.pixels + i * decompress.image_width * decompress.output_components;
 					for(row = 0; decompress.output_scanline < decompress.output_height; row += jpeg_read_scanlines(&decompress, &rows[row], decompress.output_height - row));
 					free(rows);
 					jpeg_finish_decompress(&decompress);
@@ -184,16 +232,51 @@ namespace H3D
 				else image = NULL;
 				return image;
 			}
+
+			bool
+			Save(H3D *image, const std::string &filename)
+			{
+				bool result;
+				FILE *stream; 
+				struct jpeg_compress_struct compress;
+				struct jpeg_error_mgr error;
+				unsigned char **rows;
+				unsigned int i, row;
+				stream = fopen(filename.c_str(), "wb");
+				if(stream)
+				{
+					jpeg_create_compress(&compress);
+					compress.err = jpeg_std_error(&error);
+					jpeg_stdio_dest(&compress, stream);
+					compress.image_width = image->info.width;
+					compress.image_height = image->info.height;
+					compress.input_components = image->info.bpp;
+					compress.in_color_space = JCS_RGB;
+					jpeg_set_defaults(&compress);
+					jpeg_start_compress(&compress, TRUE);
+					rows = (unsigned char **) malloc(compress.image_height * sizeof(unsigned char *));
+					for(i = 0; i < compress.image_height; i++) rows[compress.image_height - 1 - i] = image->content.pixels + i * image->info.width * image->info.bpp;
+					for(row = 0; compress.next_scanline < compress.image_height; row += jpeg_write_scanlines(&compress, &rows[row], compress.image_height - row));
+					free(rows);
+					jpeg_finish_compress(&compress);
+					jpeg_destroy_compress(&compress);
+					fclose(stream);
+
+					result = true;
+				}
+				else result = false;
+				return result;
+			}
 		}
 
 		namespace TGA
 		{
-			H3D*
-			import(const std::string& filename)
+			H3D *
+			Load(const std::string &filename)
 			{    
-				H3D* image;
+				H3D *image;
 				FILE *stream;
-				const unsigned char tgamagic[12]={0,0,2,0,0,0,0,0,0,0,0,0};
+				const unsigned char tgamagic[12]= {0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0};
 				unsigned char magic[12];
 				unsigned char header[6];
 				unsigned int width, height;
@@ -213,7 +296,7 @@ namespace H3D
 							image->info.height = (unsigned int) Math::NextTwoPower(height);
 							image->info.bpp = header[4] >> 3;
 							image->content.pixels = new unsigned char[image->info.width * image->info.height * image->info.bpp];
-							fread(image->content.pixels, 1, image->info.width * image->info.height, stream);
+							fread(image->content.pixels, 1, image->info.width * image->info.height * image->info.bpp, stream);
 							for(unsigned int i = 0; i < image->info.width * image->info.height * image->info.bpp; i += image->info.bpp)
 							{
 								GLubyte swap;
@@ -232,21 +315,57 @@ namespace H3D
 				else image = NULL;
 				return image;
 			}
+
+			bool
+			Save(H3D *image, const std::string &filename)
+			{
+				bool result;
+				FILE *stream;
+				const unsigned char magic[12]= {0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0};
+				unsigned char header[6], *pixels;
+				stream = fopen(filename.c_str(), "wb");
+				if(stream)
+				{
+					fwrite(magic, 1, sizeof(magic), stream);
+					header[0] = image->info.width & 0xFF;
+					header[1] = (image->info.width >> 8);
+					header[2] = image->info.height & 0xFF;
+					header[3] = (image->info.height >> 8);
+					header[4] = image->info.bpp << 3;
+					header[5] = 0;
+					fwrite(header, 1, sizeof(header), stream);
+					pixels = new unsigned char[image->info.width * image->info.height * image->info.bpp];
+					memcpy(pixels, image->content.pixels, image->info.width * image->info.height * image->info.bpp);
+					for(unsigned int i = 0; i < image->info.width * image->info.height * image->info.bpp; i += image->info.bpp)
+					{
+						GLubyte swap;
+						swap = pixels[i];
+						pixels[i] = pixels[i + 2];
+						pixels[i + 2] = swap;
+					}
+					fwrite(pixels, 1, image->info.width * image->info.height * image->info.bpp, stream);
+					delete pixels;
+					fclose(stream);
+					result = true;
+				}
+				else result = false;
+				return result;
+			}
 		}
 
 		namespace MIME
 		{
 			H3D*
-			import(const std::string& filename)
+			Load(const std::string& filename)
 			{
-				H3D* image;
+				H3D *image;
 				magic_t cookie;
 				const char *mime;
 				cookie = magic_open(MAGIC_MIME_TYPE |MAGIC_NO_CHECK_COMPRESS | MAGIC_NO_CHECK_TAR);
 				magic_load(cookie, NULL);
 				mime = magic_file(cookie, filename.c_str());
-				if(!strcmp(mime, "application/octet-stream")) image = PNG::import(filename);
-				else if(!strcmp(mime, "image/jpeg")) image = JPEG::import(filename);
+				if(!strcmp(mime, "application/octet-stream")) image = PNG::Load(filename);
+				else if(!strcmp(mime, "image/jpeg")) image = JPEG::Load(filename);
 				else image = NULL;
 				magic_close(cookie);
 				return image;
@@ -255,13 +374,13 @@ namespace H3D
 
 		namespace NAME
 		{
-			H3D*
-			import(const std::string& filename)
+			H3D *
+			Load(const std::string &filename)
 			{
-				H3D* image;
-				if(!(image = JPEG::import(filename + ".jpg")))
-					if(!(image = PNG::import(filename + ".png")))
-						image = TGA::import(filename + ".tga");
+				H3D *image;
+				if(!(image = JPEG::Load(filename + ".jpg")))
+					if(!(image = PNG::Load(filename + ".png")))
+						image = TGA::Load(filename + ".tga");
 				return image;
 			}
 		}
