@@ -33,7 +33,7 @@ namespace H3D
 		}
 
 		bool
-		H3D::load(const std::string& filename, bool compiled)
+		H3D::load(const std::string &filename, bool compiled)
 		{
 			bool result;
 			FILE *stream;
@@ -69,9 +69,9 @@ namespace H3D
 					for(i = 0; i < info.nvertices; i++)
 					{
 						fgets(buffer, 256, stream);
-						sscanf(buffer, "coord %f %f %f", &content.vertices[i].coord[0],&content.vertices[i].coord[1], &content.vertices[i].coord[2]);
+						sscanf(buffer, "coord %f %f %f", &content.vertices[i].coord[0], &content.vertices[i].coord[1], &content.vertices[i].coord[2]);
 						fgets(buffer, 256, stream);
-						sscanf(buffer, "normal %f %f %f", &content.vertices[i].normal[0],&content.vertices[i].normal[1], &content.vertices[i].normal[2]);
+						sscanf(buffer, "normal %f %f %f", &content.vertices[i].normal[0], &content.vertices[i].normal[1], &content.vertices[i].normal[2]);
 					}
 					fgets(buffer, 256, stream);
 					sscanf(buffer, "textures %i", &info.ntextures);
@@ -132,7 +132,7 @@ namespace H3D
 		}
 
 		bool
-		H3D::save(const std::string& filename, bool compiled)
+		H3D::save(const std::string &filename, bool compiled)
 		{
 			bool result;
 			FILE *stream;
@@ -153,7 +153,61 @@ namespace H3D
 			}
 			else
 			{
-				result = false;
+				stream = fopen(filename.c_str(), "w");
+				if(stream)
+				{
+					char buffer[256];
+					unsigned int i;
+					sprintf(buffer, "vertices %i\n", info.nvertices);
+					fputs(buffer, stream);
+					for(i = 0; i < info.nvertices; i++)
+					{
+						sprintf(buffer, "coord %f %f %f\n", content.vertices[i].coord[0], content.vertices[i].coord[1], content.vertices[i].coord[2]);
+						fputs(buffer, stream);
+						sprintf(buffer, "normal %f %f %f\n", content.vertices[i].normal[0], content.vertices[i].normal[1], content.vertices[i].normal[2]);
+						fputs(buffer, stream);
+					}
+					sprintf(buffer, "textures %i\n", info.ntextures);
+					fputs(buffer, stream);
+					for(i = 0; i < info.ntextures; i++)
+					{
+						sprintf(buffer, "name %s\n", content.textures[i].name);
+						fputs(buffer, stream);
+					}
+					sprintf(buffer, "materials %i\n", info.nmaterials);
+					fputs(buffer, stream);
+					for(i = 0; i < info.nmaterials; i++)
+					{
+						sprintf(buffer, "texture %i\n", content.materials[i].texture);
+						fputs(buffer, stream);
+						sprintf(buffer, "alpha %f\n", content.materials[i].alpha);
+						fputs(buffer, stream);
+						sprintf(buffer, "emit %f\n", content.materials[i].emit);
+						fputs(buffer, stream);
+						sprintf(buffer, "ambient %f %f %f\n", content.materials[i].ambient[0], content.materials[i].ambient[1], content.materials[i].ambient[2]);
+						fputs(buffer, stream);
+						sprintf(buffer, "diffuse %f %f %f\n", content.materials[i].diffuse[0], content.materials[i].diffuse[1], content.materials[i].diffuse[2]);
+						fputs(buffer, stream);
+						sprintf(buffer, "specular %f %f %f\n", content.materials[i].specular[0], content.materials[i].specular[1], content.materials[i].specular[2]);
+						fputs(buffer, stream);
+					}
+					sprintf(buffer, "faces %i\n", info.nfaces);
+					fputs(buffer, stream);
+					for(i = 0; i < info.nfaces; i++)
+					{
+						sprintf(buffer, "vertices %i %i %i\n", content.faces[i].vertices[0], content.faces[i].vertices[1], content.faces[i].vertices[2]);
+						fputs(buffer, stream);
+						sprintf(buffer, "texcoords %f %f %f %f %f %f\n", content.faces[i].texcoords[0][0], content.faces[i].texcoords[0][1], content.faces[i].texcoords[1][0], content.faces[i].texcoords[1][1], content.faces[i].texcoords[2][0], content.faces[i].texcoords[2][1]);
+						fputs(buffer, stream);
+						sprintf(buffer, "normal %f %f %f\n", content.faces[i].normal[0], content.faces[i].normal[1], content.faces[i].normal[2]);
+						fputs(buffer, stream);
+						sprintf(buffer, "material %i\n", content.faces[i].material);
+						fputs(buffer, stream);
+					}
+					fclose(stream);
+					result = true;
+				}
+				else result = false;
 			}
 			return result;
 		}
@@ -260,15 +314,15 @@ namespace H3D
 			}
 
 			void
-			BSP::loadGraphicData(const std::string& path)
+			BSP::loadGraphicData(const std::string &path)
 			{
 				graphicdata.textures = (GLuint *) malloc((header.direntries[1].length / sizeof(Texture)) * sizeof(GLuint));
 				glGenTextures(header.direntries[1].length / sizeof(Texture), graphicdata.textures);
 				for(unsigned int i = 0; i < header.direntries[1].length / sizeof(Texture); i++)
 				{
-					Image::H3D* image;
+					Image::H3D *image;
 
-					if((image = Image::NAME::import(path + textures[i].name)))
+					if((image = Image::NAME::Load(path + textures[i].name)))
 					{
 						glBindTexture(GL_TEXTURE_2D, graphicdata.textures[i]);
 						glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_REPEAT);
@@ -495,9 +549,9 @@ namespace H3D
 			}
 
 			H3D*
-			load(const std::string& filename)
+			load(const std::string &filename)
 			{
-				H3D* mesh;
+				H3D *mesh;
 				BSP* bsp;
 				
 				mesh = new H3D();
