@@ -34,7 +34,7 @@ namespace H3D
 		}
 
 		bool
-		H3D::load(const std::string& filename)
+		H3D::load(const std::string &filename)
 		{
 			FILE* stream;
 			bool result;
@@ -58,7 +58,7 @@ namespace H3D
 		}
 
 		bool
-		H3D::save(const std::string& filename)
+		H3D::save(const std::string &filename)
 		{
 			FILE* stream;
 			bool result;
@@ -76,10 +76,10 @@ namespace H3D
 
 		namespace VORBIS
 		{
-			H3D*
-			import(const std::string& filename)
+			H3D *
+			Load(const std::string &filename)
 			{
-				H3D* sound;
+				H3D *sound;
 				FILE *stream;
 				OggVorbis_File ogg;
 				int bitstream;
@@ -118,16 +118,16 @@ namespace H3D
 
 		namespace MIME
 		{
-			H3D*
-			import(const std::string& filename)
+			H3D *
+			Load(const std::string &filename)
 			{
-				H3D* sound;
+				H3D *sound;
 				magic_t cookie;
 				const char *mime;
 				cookie = magic_open(MAGIC_MIME_TYPE |MAGIC_NO_CHECK_COMPRESS | MAGIC_NO_CHECK_TAR);
 				magic_load(cookie, NULL);
 				mime = magic_file(cookie, filename.c_str());
-				if(!strcmp(mime, "application/ogg")) sound = VORBIS::import(filename);
+				if(!strcmp(mime, "application/ogg")) sound = VORBIS::Load(filename);
 				else sound = NULL;
 				magic_close(cookie);
 				return sound;
@@ -136,12 +136,12 @@ namespace H3D
 
 		namespace NAME
 		{
-			H3D*
-			import(const std::string& filename)
+			H3D *
+			Load(const std::string &filename)
 			{
-				H3D* sound;
-				if(!(sound = VORBIS::import(filename + ".ogg")))
-					sound = VORBIS::import(filename + ".oga");
+				H3D *sound;
+				if(!(sound = VORBIS::Load(filename + ".ogg")))
+					sound = VORBIS::Load(filename + ".oga");
 				return sound;
 			}
 		}
