@@ -19,6 +19,7 @@
 MyBox::MyBox()
 {
 	mesh = new H3D::Helper::Mesh::H3D();
+	H3D::Math::Matrix::LoadIdentity(matrix);
 }
 
 MyBox::~MyBox()
@@ -49,8 +50,10 @@ MyBox::unload(void)
 void
 MyBox::frame(void)
 {
+	H3D::Math::Matrix::RotateInPlace(matrix, H3D::Math::Vector::Y, 18);
 	glPushMatrix();
 		glTranslatef(sphere[0], sphere[1], sphere[2]);
+		glMultMatrixf(matrix);
 		mesh->draw();
 	glPopMatrix();
 }
