@@ -15,17 +15,21 @@
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 #include <stdlib.h>
-#include <string>
 #include <H3D/H3D.h>
 
 int
 main(int argc, char **argv)
 {
-	H3D::Helper::Mesh::H3D mesh;
+	int result;
+	H3D::Mesh::H3D mesh;
 
-	mesh.load(argv[1], false);
-	mesh.save(argv[2]);
-	mesh.unload();
-
-	return EXIT_SUCCESS;
+	if(argc == 3)
+	{
+		mesh.load(argv[1], false);
+		mesh.save(argv[2]);
+		mesh.unload();
+		result = EXIT_SUCCESS;
+	}
+	else result = EXIT_FAILURE;
+	return result;
 }
